@@ -13,21 +13,18 @@ import boto.rds
 import boto.ec2.elb
 import boto.ec2.autoscale
 import boto.ec2
-from boto.ec2.autoscale import LaunchConfiguration
-from boto.ec2.autoscale import AutoScalingGroup
 import boto.ec2.cloudwatch
 from boto.ec2.cloudwatch import MetricAlarm
 
-
 class Web(Tier):
     tier = "web"
-    modules = ["hive_scripts", "hadoop", "hadoop2", "hustler", "hive", "sqoop", "pig", "tapp2", "cloudman"]
+    modules = ["hive_scripts", "hadoop", "hadoop2", "hustler", "hive", "hive2", "sqoop", "pig", "tapp2", "cloudman"]
     worker = "qpal_worker"
     region = "us-east-1"
 
     def __init__(self, subparser):
         super(Web, self).__init__(subparser)
-        
+
         # sanitize-autoscaling-group
         san = self.tier_parser.add_parser("sanitize-as-group", help="Create and associate an upscaling policy with autoscaling group. ")
         san.add_argument("-r", "--region", help="Region where the tier will be located",
@@ -86,7 +83,7 @@ class Web(Tier):
         self.login_parser.add_argument("-z", "--zombies", dest="zombies",
                                 action="store_true", help="Login into a zombie node in %s" % (self.tier))
         self.login_parser.set_defaults(func=self.web_login)
-        
+
         #add new args for deploy_parser
         self.deploy_parser.add_argument("-r", "--no-rolling", dest="rolling",
                                    default=True, action="store_false",
@@ -162,7 +159,7 @@ class Web(Tier):
     def web_screen(self, args):
         output = Knife().ssh("screen", args.environment, self.tier, self.get_filter(args))
         print output
-    
+
     def get_elb(self, env):
         creds = Knife().get_credentials(env)
         return creds["lb_name"]
@@ -173,18 +170,18 @@ class Web(Tier):
     def web_deploy(self, args):
         if args.djrestart == False and args.module != "tapp2":
             raise Exception("-d argument can be specified only with -m tapp2")
-        
+
         logging.info("Trying to take a lock for deploy on " + args.environment)
         knife = Knife()
         success = knife.deploy_lock(args.environment, False, self.tier, "lock")
         if success == False:
             raise Exception("Failed to take lock for deploy. Exiting...")
-        
+
         try: 
             knife.reap_instances(args)
             temp = knife.get_pemfile(args.environment)
             creds = knife.get_credentials(args.environment) 
-            
+
             if (args.commstuff == True):
                 DeployUtils.run_common_stuff(args.environment, self.tier, temp)
 
@@ -237,20 +234,31 @@ class Web(Tier):
         knife = Knife()
         creds = knife.get_credentials(args.environment)
 
-        logging.info("Connecting to AWS using boto")
+        logging.info("applying autoscaling policy in %s" % args.environment)
         autoscale_conn = boto.ec2.autoscale.connect_to_region(
             args.region,
             aws_access_key_id=creds["access"],
             aws_secret_access_key=creds["secret"])
         as_group_name = self.as_name(args.environment)
+        logging.debug("autoscaling group for %s should be %s" % (args.environment, as_group_name))
+
+        policy_name = "%s-%s-upscale-policy" % (args.environment, self.tier)
         policies = autoscale_conn.get_all_policies(as_group=as_group_name)
         if len(policies) > 0:
-            raise Exception("Policy already exist for as group: " + str(as_group_name))
-        policy_name = "%s-%s-upscale-policy" % (args.environment, self.tier)  
-        policy = boto.ec2.autoscale.policy.ScalingPolicy(autoscale_conn, name=policy_name, adjustment_type="ChangeInCapacity", as_name=as_group_name,scaling_adjustment=1,cooldown=1200)
+            raise Exception("autoscaling policy %s:%s already exists" % (as_group_name, policies[0]))
+        policy = boto.ec2.autoscale.policy.ScalingPolicy(
+            autoscale_conn,
+            name=policy_name,
+            adjustment_type="ChangeInCapacity",
+            as_name=as_group_name,
+            scaling_adjustment=1,
+            cooldown=1200)
         autoscale_conn.create_scaling_policy(policy)
         policies = autoscale_conn.get_all_policies(as_group=as_group_name)
+        assert len(policies) == 1, "Found multiple (%s) autoscaling policies!" % as_group_name
+        logging.info("created new upscale policy %s" % policies[0])
         policy = policies[0]
+
         cw_conn = boto.ec2.cloudwatch.connect_to_region(
             args.region,
             aws_access_key_id=creds["access"],
@@ -266,26 +274,32 @@ class Web(Tier):
                 alarm_actions=[policy.policy_arn],
                 dimensions=None)
         cw_conn.create_alarm(scale_up_alarm)
-    
+        logging.info("created cloudwatch alarm %s for autoscaling policy %s" % (aname, policy_name))
+
+
     def sanitize(self, args):
-        logging.info("Getting credentials from Chef server and RDS")
+        logging.info("Begin sanitize %s autoscaling group" % args.environment)
         knife = Knife()
         creds = knife.get_credentials(args.environment)
         as_group_name = self.as_name(args.environment)
-
-        logging.info("Connecting to AWS using boto")
+        logging.debug("autoscaling group for %s should be %s" % (args.environment, as_group_name))
         autoscale_conn = boto.ec2.autoscale.connect_to_region(
             args.region,
             aws_access_key_id=creds["access"],
             aws_secret_access_key=creds["secret"])
 
+        logging.info("querying AWS for %s" % as_group_name)
         as_objs = autoscale_conn.get_all_groups([as_group_name])
         if len(as_objs) < 1:
             raise Exception("As Group: %s does not exist. First create this group "
                             "and then call sanitize" % as_group_name)
-        as_obj = as_objs[0]    
+        assert len(as_objs) == 1, "Duplicate names (%s) found for ASG!" % as_group_name
+        logging.info("autoscaling group for %s found to be %s" % (args.environment, as_objs[0]))
+        as_obj = as_objs[0]
+
         as_obj.cooldown = 1200
         as_obj.health_check_period = 600
         as_obj.update()
         as_obj.suspend_processes(["ReplaceUnhealthy"])
-
+        logging.info("ASG updated successfully: cooldown: %d healthcheck %d"
+                     % (as_obj.cooldown, as_obj.health_check_period))
