@@ -8,6 +8,7 @@ import random
 import socket
 import os
 import yaml
+import json
 import paramiko
 from qds_ops.utils.fork import Fork
 from qds_ops.utils.ssh_tunnel import SSHTunnel
@@ -101,6 +102,25 @@ puts nodeinfo.to_json""" % (env, tier)
             logging.debug("Obtained creds from cache")
         return self.creds
 
+    def update_data_bag(self, environment, json_obj):
+        output = Fork.check_output(["knife", "data", "bag", "show", "creds",
+                                    "env_%s" % (environment), "--secret-file",
+                                    "/etc/chef/encrypted_data_bag_secret",
+                                    "-f", "json"], stderr=None)
+        data = json.loads(output)
+        for key, value in json_obj.iteritems():
+            data[key] = value
+
+        filename = "/tmp/%s.json" %environment
+        with open(filename, "w") as f:
+            f.write(json.dumps(data))
+            logging.debug("""Created the data bag json file with updated
+                key/value pair""")
+            logging.info("File is saved at %s Run following command to upload"
+                %filename)
+            logging.info("knife data bag from file creds %s --secret-file /etc/chef/encrypted_data_bag_secret" %filename)
+        
+
     def get_pemfile(self, env):
         if self.pemfile is None:
             creds = self.get_credentials(env)
